Anwendungsprofile erstellen und konfigurieren
Mit Bigtable-Anwendungsprofilen (Anwendungsprofilen) können Sie Routingrichtlinien, Computing-Optionen und Einstellungen zur Arbeitslastisolierung für eingehende Clientanfragen angeben. Sie können Traffic über bereitgestellte Clusterknoten leiten, isolierte Lesevorgänge mit hohem Durchsatz mithilfe von serverlosem Computing von Data Boost ausführen oder Punktlesevorgänge an eine In-Memory-Ebene (Vorschau) auf Enterprise Plus-Instanzen weiterleiten.
Hinweis
Bevor Sie ein Anwendungsprofil erstellen oder konfigurieren, lesen Sie die folgende Dokumentation:
- Unter Anwendungsprofile – Übersicht erfahren Sie, wie Anwendungsprofile funktionieren und was der Unterschied zwischen einem Standard-Anwendungsprofil für Standard-Computing und einem Data Boost-Anwendungsprofil für serverlose Lesejobs mit hohem Durchsatz ist. Weitere Informationen dazu, wie sich Data Boost von Computing mit bereitgestellten Clusterknoten unterscheidet, finden Sie unter Bigtable Data Boost – Übersicht.
- Wenn Sie Standard-Anwendungsprofile zum Konfigurieren der Replikation verwenden, lesen Sie die Informationen unter Übersicht über die Replikation und Beispiele für Replikationskonfigurationen, um zu entscheiden, welche Einstellungen für Ihren Anwendungsfall am besten geeignet sind.
- Wenn Sie ein Anwendungsprofil mit In-Memory-Stufe verwenden, lesen Sie die Übersicht über die In-Memory-Stufe.
Erforderliche Rollen
Bitten Sie Ihren Administrator, Ihnen die IAM-Rolle Bigtable-Administrator (roles/bigtable.admin) für die Instanz zuzuweisen, um die Berechtigungen zu erhalten, die Sie zum Erstellen, Konfigurieren oder Löschen eines Anwendungsprofils benötigen.
Weitere Informationen zum Zuweisen von Rollen finden Sie unter Zugriff auf Projekte, Ordner und Organisationen verwalten.
Sie können die erforderlichen Berechtigungen auch über benutzerdefinierte Rollen oder andere vordefinierte Rollen erhalten.
Anwendungsprofil erstellen
Sie können viele verschiedene benutzerdefinierte App-Profile für jede Instanz erstellen. Benutzerdefinierte App-Profile dienen dazu, die Interaktion der einzelnen Anwendung oder Anwendungsfunktion mit einer Instanz zu steuern. Sie können beispielsweise ein Anwendungsprofil für eine Batchanwendung verwenden, um den Traffic auf einen einzelnen Cluster zu beschränken, und ein anderes Anwendungsprofil, um Hochverfügbarkeit für eine andere Anwendung bereitzustellen.
Standardanwendungsprofil erstellen
So erstellen Sie ein Standard-Anwendungsprofil:
Console
Öffnen Sie in der Google Cloud Console die Liste der Bigtable-Instanzen.
Klicken Sie auf die Instanz, für die Sie das Anwendungsprofil erstellen möchten.
Klicken Sie im linken Bereich auf Anwendungsprofile.
Klicken Sie auf Anwendungsprofil erstellen.
Wähle Standard aus.
Klicken Sie auf Weiter.
Geben Sie die Anwendungsprofil-ID ein.
Die Anwendungsprofil-ID ist eine permanente Kennzeichnung für das App-Profil. Ihre Anwendung gibt diese ID an, wenn sie eine Verbindung zu Bigtable herstellt.
Geben Sie eine Beschreibung des App-Profils ein.
Wählen Sie unter Cluster-Routing entweder Single-Cluster-Routing oder Multi-Cluster-Routing aus. Weitere Informationen
Wenn Sie Single-Cluster auswählen:
Wählen Sie in der Liste Cluster den Cluster aus, an den Anfragen weitergeleitet werden sollen.
Wenn Sie Transaktionen für einzelne Zeilen aktivieren müssen, setzen Sie ein Häkchen bei Transaktionen für einzelne Zeilen zulassen.
Wenn Sie Multi-Cluster auswählen:
- Wählen Sie in der Liste Clustergruppe die Option Beliebiger Cluster aus, um Anfragen an einen beliebigen Cluster in der Instanz weiterzuleiten.
- Wenn Sie das Anfrage-Routing auf einige Cluster in der Instanz beschränken möchten (Clustergruppen-Routing), wählen Sie jeden Cluster aus, den Sie in die Routinggruppe aufnehmen möchten, und klicken Sie dann auf OK.
- Wenn Sie Lese- und Schreibanfragen für einzelne Zeilen basierend auf dem Zeilenschlüssel der Anfrage an einen bestimmten Cluster weiterleiten möchten, wählen Sie Zeilenaffinität aktivieren aus.
Weisen Sie Ihren Anfragen unter Routingpriorität auswählen eine Routingpriorität zu, indem Sie eine der folgenden Optionen auswählen:
- Hoch: Für latenzempfindliche Anfragen verwenden
- Mittel: Für allgemeine Zwecke verwenden
- Niedrig: Für Hintergrundaufgaben oder weniger zeitkritische Vorgänge verwenden.
Klicken Sie auf Erstellen, um das Anwendungsprofil zu erstellen.
Aktualisieren Sie Ihren Anwendungscode zur Verbindungsherstellung mit Bigtable so, dass das neue App-Profil verwendet wird.
gcloud
Wenn Sie die Instanz-ID nicht kennen, verwenden Sie den Befehl
bigtable instances list, um eine Liste der Instanzen des Projekts aufzurufen:gcloud bigtable instances listVerwenden Sie den Befehl
bigtable app-profiles create, um ein Anwendungsprofil zu erstellen:gcloud bigtable app-profiles create APP_PROFILE_ID \ --instance=INSTANCE_ID \ [--description=DESCRIPTION] \ [--force] \ [--route-any] \ [--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...] \ [--route-to=CLUSTER_ID] \ [--transactional-writes] \ [--priority=PRIORITY] \ [--row-affinity]Machen Sie folgende Angaben:
APP_PROFILE_ID: Die permanente Kennzeichnung des Anwendungsprofils.INSTANCE_ID: Die permanente Kennzeichnung der Instanz
Der Befehl akzeptiert die folgenden optionalen Flags:
--description=DESCRIPTION: Eine detaillierte Beschreibung des Anwendungsprofils.--force: Warnungen zu potenziellen Problemen und Konflikten mit anderen Anwendungsprofilen werden ignoriert.--route-any: Aktivieren Sie Multi-Cluster-Routing, um Anfragen an einen beliebigen verfügbaren Cluster weiterzuleiten.Dieses Flag darf nicht mit den Flags
--route-tooder--transactional-writeskombiniert werden.--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...: Eine Liste der Cluster, an die Anfragen weitergeleitet werden sollen. Verwenden Sie diese Option, wenn Sie Anfragen nur an einige der Cluster in der Instanz weiterleiten möchten.Dieses Flag darf nicht mit den Flags
--route-tooder--transactional-writeskombiniert werden.--route-to=CLUSTER_ID: Die Cluster-ID, an die alle Anfragen weitergeleitet werden sollen. Dieses Flag aktiviert Single-Cluster-Routing.Dieses Flag darf nicht mit dem Flag
--route-anykombiniert werden.--transactional-writes: Aktivieren Sie einzeilige Transaktionen im Anwendungsprofil.Dieses Flag darf nicht mit dem Flag
--route-anyoder--restrict-tokombiniert werden.--priority=PRIORITY: Die Prioritätsstufe, die das Anwendungsprofil verwenden soll. Zulässige Werte sindPRIORITY_HIGH,PRIORITY_MEDIUModerPRIORITY_LOW.--row-affinity: Aktivieren Sie Zeilenaffinitätsrouting im Anwendungsprofil.Dieses Flag darf nicht mit den Flags
--route-tooder--transactional-writeskombiniert werden.
Aktualisieren Sie Ihren Anwendungscode zur Verbindungsherstellung mit Bigtable so, dass das neue App-Profil verwendet wird.
Anwendungsprofil für die In-Memory-Stufe erstellen
So erstellen Sie ein Anwendungsprofil in einem Cluster mit aktivierter In-Memory-Stufe:
Console
Öffnen Sie in der Google Cloud Console die Liste der Bigtable-Instanzen.
Klicken Sie auf die Instanz, für die Sie das Anwendungsprofil erstellen möchten.
Klicken Sie im linken Bereich auf Anwendungsprofile.
Klicken Sie auf Anwendungsprofil erstellen.
Wählen Sie In-Memory-Stufe aus.
Klicken Sie auf Weiter.
Geben Sie die Anwendungsprofil-ID ein.
Die Anwendungsprofil-ID ist eine permanente Kennzeichnung für das App-Profil. Ihre Anwendung gibt diese ID an, wenn sie eine Verbindung zu Bigtable herstellt.
Geben Sie eine Beschreibung des App-Profils ein.
Wählen Sie unter Cluster-Routing einen Cluster mit aktivierter In-Memory-Stufe aus.
Cluster mit In-Memory-Stufe müssen Single-Cluster-Routing verwenden.
Wenn Sie Transaktionen für einzelne Zeilen aktivieren müssen, wählen Sie Transaktionen für einzelne Zeilen zulassen aus.
Weisen Sie Ihren Anfragen unter Routingpriorität auswählen eine Routingpriorität zu, indem Sie eine der folgenden Optionen auswählen:
- Hoch: Für latenzempfindliche Anfragen verwenden
- Mittel: Für allgemeine Zwecke verwenden
- Niedrig: Für Hintergrundaufgaben oder weniger zeitkritische Vorgänge verwenden.
Klicken Sie auf Erstellen, um das App-Profil zu erstellen.
Aktualisieren Sie Ihren Anwendungscode zur Verbindungsherstellung mit Bigtable so, dass das neue App-Profil verwendet wird.
gcloud
Wenn Sie die Instanz-ID nicht kennen, verwenden Sie den Befehl
bigtable instances list, um eine Liste der Instanzen des Projekts aufzurufen:gcloud bigtable instances listVerwenden Sie den Befehl
gcloud beta bigtable app-profiles create, um ein Anwendungsprofil zu erstellen:gcloud beta bigtable app-profiles create APP_PROFILE_ID \ --instance=INSTANCE_ID \ --route-to=CLUSTER_ID \ --use-memory-layer \ [--description=DESCRIPTION] \ [--transactional-writes] \ [--priority=PRIORITY]Machen Sie folgende Angaben:
APP_PROFILE_ID: Die permanente Kennzeichnung des Anwendungsprofils.INSTANCE_ID: Die permanente Kennzeichnung der Instanz
Der Befehl akzeptiert die folgenden optionalen Flags:
--route-to=CLUSTER_ID: Die Cluster-ID, an die alle Anfragen weitergeleitet werden sollen. Dieses Flag aktiviert Single-Cluster-Routing.--use-memory-layer: Anfragen mit diesem Anwendungsprofil werden an die In-Memory-Stufe weitergeleitet. Dieses Flag ist auf die Enterprise Plus-Version und das Single-Cluster-Routing beschränkt.--description=DESCRIPTION: Eine detaillierte Beschreibung des Anwendungsprofils.--transactional-writes: Aktivieren Sie einzeilige Transaktionen im Anwendungsprofil.--priority=PRIORITY: Die Prioritätsstufe von Anfragen, die über das Anwendungsprofil gesendet werden. Zulässige Werte sindPRIORITY_HIGH,PRIORITY_MEDIUModerPRIORITY_LOW. Anfrageprioritäten haben keine Auswirkungen auf Anfragen, die für die In-Memory-Stufe infrage kommen.
Aktualisieren Sie Ihren Anwendungscode zur Verbindungsherstellung mit Bigtable so, dass das neue App-Profil verwendet wird.
Data Boost-Anwendungsprofil erstellen
So erstellen Sie ein Data Boost-Anwendungsprofil, das serverloses Computing von Data Boost verwendet: Prüfen Sie die Einschränkungen, um sicherzustellen, dass Ihre Arbeitslast mit Data Boost kompatibel ist.
Console
Öffnen Sie in der Google Cloud Console die Liste der Bigtable-Instanzen.
Klicken Sie auf die Instanz, für die Sie das Anwendungsprofil erstellen möchten.
Klicken Sie im linken Bereich auf Anwendungsprofile.
Klicken Sie auf Anwendungsprofil erstellen.
Wählen Sie Data Boost aus.
Klicken Sie auf Weiter.
Geben Sie die Anwendungsprofil-ID ein.
Die Anwendungsprofil-ID ist eine permanente Kennzeichnung für das App-Profil. Ihre Anwendung gibt diese ID an, wenn sie eine Verbindung zu Bigtable herstellt.
Geben Sie eine Beschreibung des App-Profils ein.
Wählen Sie unter Clusterrouting den Cluster aus, an den Anfragen weitergeleitet werden sollen.
Klicken Sie auf Anwendungsprofil erstellen, um das Anwendungsprofil zu erstellen.
Aktualisieren Sie Ihren Anwendungscode zur Verbindungsherstellung mit Bigtable so, dass das neue App-Profil verwendet wird.
gcloud
Wenn Sie die Instanz-ID nicht kennen, verwenden Sie den Befehl
bigtable instances list, um eine Liste der Instanzen des Projekts aufzurufen:gcloud bigtable instances listVerwenden Sie den Befehl
gcloud beta bigtable app-profiles create, um ein Anwendungsprofil zu erstellen:gcloud bigtable app-profiles create APP_PROFILE_ID \ --instance=INSTANCE_ID \ --data-boost \ --data-boost-compute-billing-owner=HOST_PAYS \ --route-to=CLUSTER_IDMachen Sie folgende Angaben:
APP_PROFILE_ID: Die permanente Kennzeichnung des Anwendungsprofils.INSTANCE_ID: Die permanente Kennzeichnung der InstanzCLUSTER_ID: Die Cluster-ID, an die alle Anfragen weitergeleitet werden sollen. Dieses Flag aktiviert Single-Cluster-Routing.
Mit einem benutzerdefinierten Anwendungsprofil verbinden
Nachdem Sie ein benutzerdefiniertes Anwendungsprofil erstellt haben, können Sie Ihren Code so aktualisieren, dass Ihre Anwendung beim Verbinden mit Bigtable das Anwendungsprofil verwendet.
Die folgenden Beispiele zeigen, wie Sie ein Anwendungsprofil angeben, wenn Ihre Anwendung einen Bigtable-Client erstellt und eine Verbindung zu einer Instanz herstellt. Ersetzen Sie [APP_PROFILE_ID] durch den entsprechenden Wert.
C#
var client = BigtableClient.Create(appProfileId: "[APP_PROFILE_ID]");Go
clientConf := bigtable.ClientConfig{AppProfile:"[APP_PROFILE_ID]"}
client, err = bigtable.NewClientWithConfig(ctx, project, instance, clientConf)HBase Java
// If using BigtableOptions directly:
optionsBuilder.setAppProfileId("[APP_PROFILE_ID]");
// If using BigtableOptionsFactory:
configuration.set(BigtableOptionsFactory.APP_PROFILE_ID_KEY, "[APP_PROFILE_ID]");
// If using system properties, set "google.bigtable.app_profile.id" to
// "[APP_PROFILE_ID]"
// If using CloudBigtableIO for Cloud Dataflow:
config.withConfiguration(BigtableOptionsFactory.APP_PROFILE_ID_KEY,
"[APP_PROFILE_ID]");Node.js
const bigtable = new Bigtable({appProfileId: '[APP_PROFILE_ID]'});Python
from google.cloud import bigtable
client = bigtable.Client(project=project_id)
instance = client.instance(instance_id)
table = bigtable.table.Table(table_id, instance, '[APP_PROFILE_ID]')Anwendungsprofil aktualisieren
Sie können die App-Profile einer Instanz jederzeit aufrufen und deren Einstellungen aktualisieren. Dabei gibt Bigtable immer dann eine Warnung aus, wenn eine Aktualisierung zu unerwarteten Änderungen im Verhalten führen könnte.
Informationen zum Aktualisieren eines Anwendungsprofils von Standard auf Data Boost oder von Data Boost auf Standard finden Sie unter Anwendungsprofil konvertieren.
Standardanwendungsprofil aktualisieren
So aktualisieren Sie ein Standard-Anwendungsprofil:
Console
Öffnen Sie in der Google Cloud Console die Liste der Bigtable-Instanzen.
Klicken Sie auf die Instanz mit dem Anwendungsprofil, das Sie aktualisieren möchten.
Klicken Sie im linken Bereich auf Anwendungsprofile.
Klicken Sie für das Anwendungsprofil, das Sie aktualisieren möchten, auf Anwendungsprofil bearbeiten.
Aktualisieren Sie die Einstellungen nach Bedarf.
Klicken Sie auf Speichern oder auf Abbrechen, um den Vorgang zu beenden, ohne die Änderungen zu übernehmen.
gcloud
Wenn Sie die Instanz-ID nicht kennen, verwenden Sie den Befehl
bigtable instances list, um eine Liste der Instanzen des Projekts aufzurufen:gcloud bigtable instances listWenn Sie die ID des Anwendungsprofils nicht kennen, verwenden Sie den Befehl
bigtable app-profiles list, um eine Liste der Anwendungsprofile der Instanz aufzurufen:gcloud bigtable app-profiles list --instance=INSTANCE_IDErsetzen Sie
INSTANCE_IDdurch die permanente Kennzeichnung der Instanz.Optional: Verwenden Sie den Befehl
bigtable app-profiles describe, um die Einstellungen des Anwendungsprofils aufzurufen:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDMachen Sie folgende Angaben:
APP_PROFILE_ID: Die permanente Kennzeichnung des Anwendungsprofils.INSTANCE_ID: Die permanente Kennzeichnung der Instanz
Verwenden Sie den Befehl
bigtable app-profiles update, um die Einstellungen des Anwendungsprofils zu aktualisieren:gcloud bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ [--description=DESCRIPTION] \ [--force] \ [--route-any] \ [--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...] [--route-to=CLUSTER_ID] \ [--transactional-writes] \ [--row-affinity]Machen Sie folgende Angaben:
APP_PROFILE_ID: Die permanente Kennzeichnung des Anwendungsprofils.INSTANCE_ID: Die permanente Kennzeichnung der Instanz
Der Befehl akzeptiert die folgenden optionalen Flags:
--description=DESCRIPTION: Eine detaillierte Beschreibung des Anwendungsprofils.--force: Warnungen zu potenziellen Problemen und Konflikten mit anderen Anwendungsprofilen werden ignoriert.--route-any: Aktivieren Sie Multi-Cluster-Routing, um Anfragen an einen beliebigen verfügbaren Cluster weiterzuleiten.Dieses Flag darf nicht mit den Flags
--route-tooder--transactional-writeskombiniert werden.--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...: Eine Liste der Cluster, an die Anfragen weitergeleitet werden sollen. Verwenden Sie diese Option, wenn Sie Anfragen nur an einige der Cluster in der Instanz weiterleiten möchten.Dieses Flag darf nicht mit den Flags
--route-tooder--transactional-writeskombiniert werden.--route-to=CLUSTER_ID: Die Cluster-ID, an die alle Anfragen weitergeleitet werden sollen. Dieses Flag aktiviert Single-Cluster-Routing.Dieses Flag darf nicht mit dem Flag
--route-anykombiniert werden.--transactional-writes: Aktivieren Sie einzeilige Transaktionen im Anwendungsprofil.Dieses Flag darf nicht mit dem Flag
--route-anykombiniert werden.--priority=PRIORITY: Die Prioritätsstufe, die das Anwendungsprofil verwendet. Zulässige Werte sindPRIORITY_HIGH,PRIORITY_MEDIUModerPRIORITY_LOW.
Anwendungsprofil mit In-Memory-Stufe aktualisieren
So aktualisieren Sie ein Anwendungsprofil in einem Cluster mit aktivierter In-Memory-Stufe:
Console
Öffnen Sie in der Google Cloud Console die Liste der Bigtable-Instanzen.
Klicken Sie auf die Instanz mit dem Anwendungsprofil, das Sie aktualisieren möchten.
Klicken Sie im linken Bereich auf Anwendungsprofile.
Klicken Sie für das Anwendungsprofil, das Sie aktualisieren möchten, auf Anwendungsprofil bearbeiten.
Aktualisieren Sie die Einstellungen nach Bedarf.
Klicken Sie auf Speichern oder auf Abbrechen, um den Vorgang zu beenden, ohne die Änderungen zu übernehmen.
gcloud
Wenn Sie die Instanz-ID nicht kennen, verwenden Sie den Befehl
bigtable instances list, um eine Liste der Instanzen des Projekts aufzurufen:gcloud bigtable instances listWenn Sie die ID des Anwendungsprofils nicht kennen, verwenden Sie den Befehl
bigtable app-profiles list, um eine Liste der Anwendungsprofile der Instanz aufzurufen:gcloud bigtable app-profiles list --instance=INSTANCE_IDErsetzen Sie
INSTANCE_IDdurch die permanente Kennzeichnung der Instanz.Optional: Verwenden Sie den Befehl
gcloud bigtable app-profiles describe, um die Einstellungen des Anwendungsprofils aufzurufen:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDMachen Sie folgende Angaben:
APP_PROFILE_ID: Die permanente Kennzeichnung des Anwendungsprofils.INSTANCE_ID: Die permanente Kennzeichnung der Instanz
Verwenden Sie den Befehl
gcloud beta bigtable app-profiles update, um die Einstellungen des Anwendungsprofils zu aktualisieren:gcloud beta bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ --route-to=CLUSTER_ID \ [--description=DESCRIPTION] \ [--transactional-writes] \ [--priority=PRIORITY] \ [--use-memory-layer] \ [--no-use-memory-layer]Machen Sie folgende Angaben:
APP_PROFILE_ID: Die permanente Kennzeichnung des Anwendungsprofils.INSTANCE_ID: Die permanente Kennzeichnung der Instanz
Der Befehl akzeptiert die folgenden optionalen Flags:
--description=DESCRIPTION: Eine detaillierte Beschreibung des Anwendungsprofils.--route-to=CLUSTER_ID: Die Cluster-ID, an die alle Anfragen weitergeleitet werden sollen. Dieses Flag aktiviert Single-Cluster-Routing.--transactional-writes: Aktivieren Sie einzeilige Transaktionen im Anwendungsprofil.--priority=PRIORITY: Die Prioritätsstufe, die das Anwendungsprofil verwendet. Zulässige Werte sindPRIORITY_HIGH,PRIORITY_MEDIUModerPRIORITY_LOW.--use-memory-layer: Anfragen mit diesem Anwendungsprofil werden an die In-Memory-Stufe weitergeleitet. Verwenden Sie--no-use-memory-layer, um das Routing der In-Memory-Stufe für dieses Anwendungsprofil zu deaktivieren. Dieses Flag ist auf die Enterprise Plus-Version und das Single-Cluster-Routing beschränkt.
Data Boost-Anwendungsprofil aktualisieren
So aktualisieren Sie den Cluster, aus dem ein Data Boost-Anwendungsprofil liest:
Console
Öffnen Sie in der Google Cloud Console die Liste der Bigtable-Instanzen.
Klicken Sie in der Spalte Anwendungsprofile auf das Anwendungsprofil, das Sie ansehen oder aktualisieren möchten.
Wenn Sie das Anwendungsprofil, das Sie bearbeiten möchten, nicht sehen, können Sie eine vollständige Liste aufrufen, indem Sie auf den Namen der Instanz und dann im linken Bereich auf Anwendungsprofile klicken.
Wählen Sie den neuen Cluster aus, an den der Traffic weitergeleitet werden soll, und klicken Sie dann auf Speichern.
gcloud
Wenn Sie die Instanz-ID nicht kennen, verwenden Sie den Befehl
bigtable instances list, um eine Liste der Instanzen des Projekts aufzurufen:gcloud bigtable instances listWenn Sie die ID des Anwendungsprofils nicht kennen, verwenden Sie den Befehl
bigtable app-profiles list, um eine Liste der Anwendungsprofile der Instanz aufzurufen:gcloud bigtable app-profiles list --instance=INSTANCE_IDErsetzen Sie
INSTANCE_IDdurch die permanente Kennzeichnung der Instanz.Optional: Verwenden Sie den Befehl
gcloud bigtable app-profiles describe, um die Einstellungen des Anwendungsprofils aufzurufen:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDMachen Sie folgende Angaben:
APP_PROFILE_ID: Die permanente Kennzeichnung des Anwendungsprofils.INSTANCE_ID: Die permanente Kennzeichnung der Instanz
Verwenden Sie den Befehl
gcloud beta bigtable app-profiles update, um die Einstellungen des Anwendungsprofils zu aktualisieren:gcloud beta bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ --route-to=CLUSTER_IDMachen Sie folgende Angaben:
APP_PROFILE_ID: Die permanente Kennzeichnung des Anwendungsprofils.INSTANCE_ID: Die permanente Kennzeichnung der InstanzCLUSTER_ID: die ID des neuen Clusters, aus dem gelesen werden soll
Anwendungsprofil konvertieren
Sie können ein Standard-Anwendungsprofil in ein Data Boost-Anwendungsprofil umwandeln oder ein Data Boost-Anwendungsprofil in ein Standard-Anwendungsprofil umwandeln. Bevor Sie ein Anwendungsprofil konvertieren, lesen Sie die Anleitung unter Änderungen am Anwendungsprofil.
Von Standard auf Data Boost umstellen
Bevor Sie ein Anwendungsprofil von Standard (bereitgestellte Knoten für Computing) auf serverloses Computing von Data Boost aktualisieren, prüfen Sie die Messwerte zur Data Boost-Eignung. Beachten Sie auch die Einschränkungen von Data Boost.
Console
Öffnen Sie in der Google Cloud Console die Liste der Bigtable-Instanzen.
Klicken Sie in der Spalte Anwendungsprofile auf das Anwendungsprofil, das Sie aktualisieren möchten.
Wenn Sie das zu bearbeitende Anwendungsprofil nicht finden, können Sie eine vollständige Liste abrufen. Klicken Sie dazu auf den Namen der Instanz und dann im linken Bereich auf Anwendungsprofile.
Wählen Sie Data Boost aus.
Wählen Sie den Cluster aus, an den Anfragen weitergeleitet werden sollen.
Klicken Sie auf Speichern.
gcloud
Wenn Sie die Instanz-ID nicht kennen, verwenden Sie den Befehl
bigtable instances list, um eine Liste der Instanzen des Projekts aufzurufen:gcloud bigtable instances listWenn Sie die ID des Anwendungsprofils nicht kennen, verwenden Sie den Befehl
bigtable app-profiles list, um eine Liste der Anwendungsprofile der Instanz aufzurufen:gcloud bigtable app-profiles list --instance=INSTANCE_IDErsetzen Sie
INSTANCE_IDdurch die permanente Kennzeichnung der Instanz.Optional: Verwenden Sie den Befehl
bigtable app-profiles describe, um die Einstellungen des Anwendungsprofils aufzurufen:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDMachen Sie folgende Angaben:
APP_PROFILE_ID: Die permanente Kennzeichnung des Anwendungsprofils.INSTANCE_ID: Die permanente Kennzeichnung der Instanz
Verwenden Sie den Befehl
gcloud beta bigtable app-profiles update, um ein Anwendungsprofil von Standard in Data Boost umzuwandeln:gcloud bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ --data-boost \ --data-boost-compute-billing-owner=HOST_PAYS \ --route-to=CLUSTER_IDMachen Sie folgende Angaben:
APP_PROFILE_ID: Die permanente Kennzeichnung des Anwendungsprofils.INSTANCE_ID: Die permanente Kennzeichnung der InstanzCLUSTER_ID: Die Cluster-ID, an die alle Anfragen weitergeleitet werden sollen. Dieses Flag aktiviert Single-Cluster-Routing.
Von Data Boost auf Standard umstellen
So ändern Sie ein Anwendungsprofil von der Verwendung von Data Boost (serverloses Computing) zu Standard (bereitgestellte Knoten für Computing):
Console
Öffnen Sie in der Google Cloud Console die Liste der Bigtable-Instanzen.
Klicken Sie in der Spalte Anwendungsprofile auf das Anwendungsprofil, das Sie aktualisieren möchten.
Wenn Sie das zu bearbeitende Anwendungsprofil nicht finden, können Sie eine vollständige Liste abrufen. Klicken Sie dazu auf den Namen der Instanz und dann im linken Bereich auf Anwendungsprofile.
Wähle Standard aus.
Klicken Sie auf Weiter.
Optional: Bearbeiten Sie die Beschreibung des Anwendungsprofils.
Wählen Sie unter Cluster-Routing entweder Single-Cluster-Routing oder Multi-Cluster-Routing aus. Weitere Informationen
Wenn Sie Single-Cluster auswählen:
Wählen Sie in der Liste Cluster den Cluster aus, an den Anfragen weitergeleitet werden sollen.
Wenn Sie Transaktionen für einzelne Zeilen aktivieren müssen, setzen Sie ein Häkchen bei Transaktionen für einzelne Zeilen zulassen.
Wenn Sie Multi-Cluster auswählen:
- Wählen Sie in der Liste Clustergruppe die Option Beliebiger Cluster aus, um Anfragen an einen beliebigen Cluster in der Instanz weiterzuleiten.
- Wenn Sie das Anfrage-Routing auf einige Cluster in der Instanz beschränken möchten (Clustergruppen-Routing), wählen Sie jeden Cluster aus, den Sie in die Routinggruppe aufnehmen möchten, und klicken Sie dann auf OK.
- Wenn Sie Lese- und Schreibanfragen für einzelne Zeilen basierend auf dem Zeilenschlüssel der Anfrage an einen bestimmten Cluster weiterleiten möchten, wählen Sie Zeilenaffinität aktivieren aus.
Weisen Sie Ihren Anfragen unter Routingpriorität auswählen eine Routingpriorität zu, indem Sie eine der folgenden Optionen auswählen:
- Hoch: Für latenzempfindliche Anfragen verwenden
- Mittel: Für allgemeine Zwecke verwenden
- Niedrig: Für Hintergrundaufgaben oder weniger zeitkritische Vorgänge verwenden.
Klicken Sie auf Speichern.
gcloud
Wenn Sie die Instanz-ID nicht kennen, verwenden Sie den Befehl
bigtable instances list, um eine Liste der Instanzen des Projekts aufzurufen:gcloud bigtable instances listWenn Sie die ID des Anwendungsprofils nicht kennen, verwenden Sie den Befehl
bigtable app-profiles list, um eine Liste der Anwendungsprofile der Instanz aufzurufen:gcloud bigtable app-profiles list --instance=INSTANCE_IDErsetzen Sie
INSTANCE_IDdurch die permanente Kennzeichnung der Instanz.Optional: Verwenden Sie den Befehl
bigtable app-profiles describe, um die Einstellungen des Anwendungsprofils aufzurufen:gcloud bigtable app-profiles describe APP_PROFILE_ID \ --instance=INSTANCE_IDVerwenden Sie den Befehl
gcloud beta bigtable app-profiles update, um das Anwendungsprofil zu konvertieren:gcloud bigtable app-profiles update APP_PROFILE_ID \ --instance=INSTANCE_ID \ --standard \ [--route-any] \ [--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...] [--route-to=CLUSTER_ID] \ [--transactional-writes]
Machen Sie folgende Angaben:
APP_PROFILE_ID: Die permanente Kennzeichnung des Anwendungsprofils.INSTANCE_ID: Die permanente Kennzeichnung der Instanz
Der Befehl akzeptiert die folgenden optionalen Flags:
--route-any: Aktivieren Sie Multi-Cluster-Routing, um Anfragen an einen beliebigen verfügbaren Cluster weiterzuleiten.Dieses Flag darf nicht mit den Flags
--route-tooder--transactional-writeskombiniert werden.--restrict-to=CLUSTER_ID_1, CLUSTER_ID_2...: Eine Liste der Cluster, an die Anfragen weitergeleitet werden sollen. Verwenden Sie diese Option, wenn Sie Anfragen nur an einige der Cluster in der Instanz weiterleiten möchten.Dieses Flag darf nicht mit den Flags
--route-tooder--transactional-writeskombiniert werden.--route-to=CLUSTER_ID: Die Cluster-ID, an die alle Anfragen weitergeleitet werden sollen. Dieses Flag aktiviert Single-Cluster-Routing.Dieses Flag darf nicht mit dem Flag
--route-anykombiniert werden.--transactional-writes: Aktivieren Sie einzeilige Transaktionen im Anwendungsprofil.Dieses Flag darf nicht mit den Flags
--route-anyoder--restrict-tokombiniert werden.
Anwendungsprofil löschen
Sie können die benutzerdefinierten App-Profile einer Instanz löschen, nicht jedoch das standardmäßige App-Profil.
So löschen Sie ein benutzerdefiniertes App-Profil:
Console
Öffnen Sie in der Google Cloud Console die Liste der Bigtable-Instanzen.
Klicken Sie auf die Instanz, die das zu löschende Anwendungsprofil enthält.
Klicken Sie im linken Bereich auf Anwendungsprofile.
Öffnen Sie das Dreipunkt-Menü und klicken Sie dann auf Anwendungsprofil löschen. Ein Bestätigungsdialog wird geöffnet.
Folgen Sie der Anleitung im Bestätigungsdialogfeld und klicken Sie dann auf Löschen.
gcloud
Wenn Sie die Instanz-ID nicht kennen, verwenden Sie den Befehl
bigtable instances list, um eine Liste der Instanzen des Projekts aufzurufen:gcloud bigtable instances listWenn Sie die ID des Anwendungsprofils nicht kennen, verwenden Sie den Befehl
bigtable app-profiles list, um eine Liste der Anwendungsprofile der Instanz aufzurufen:gcloud bigtable app-profiles list --instance=INSTANCE_IDErsetzen Sie
INSTANCE_IDdurch die permanente Kennzeichnung der Instanz.Verwenden Sie den Befehl
bigtable app-profiles delete, um das Anwendungsprofil zu löschen:gcloud bigtable app-profiles delete APP_PROFILE_ID \ --instance=INSTANCE_ID \ [--force]Machen Sie folgende Angaben:
APP_PROFILE_ID: Die permanente Kennzeichnung des Anwendungsprofils.INSTANCE_ID: Die permanente Kennzeichnung der Instanz
Der Befehl akzeptiert das folgende optionale Flag:
--force: Warnungen zu potenziellen Problemen und Konflikten mit anderen Anwendungsprofilen werden ignoriert.